@@ -5,25 +5,22 @@ use strict;
 use Apache::Session;
 use Apache::Session::Lock::Null;
 use Apache::Session::Browseable::Store::MySQL;
-use Apache::Session::Generate::MD5;
-use Apache::Session::Serialize::Storable;
+use Apache::Session::Generate::SHA256;
+use Apache::Session::Serialize::JSON;
 use Apache::Session::Browseable::DBI;
 
-our $VERSION = '0.8';
+our $VERSION = '1.2';
 our @ISA     = qw(Apache::Session::Browseable::DBI Apache::Session);
 
-*serialize   = \&Apache::Session::Serialize::Storable::serialize;
-*unserialize = \&Apache::Session::Serialize::Storable::unserialize;
-
 sub populate {
     my $self = shift;
 
     $self->{object_store} = new Apache::Session::Browseable::Store::MySQL $self;
     $self->{lock_manager} = new Apache::Session::Lock::Null $self;
-    $self->{generate}     = \&Apache::Session::Generate::MD5::generate;
-    $self->{validate}     = \&Apache::Session::Generate::MD5::validate;
-    $self->{serialize}    = \&serialize;
-    $self->{unserialize}  = \&unserialize;
+    $self->{generate}     = \&Apache::Session::Generate::SHA256::generate;
+    $self->{validate}     = \&Apache::Session::Generate::SHA256::validate;
+    $self->{serialize}    = \&Apache::Session::Serialize::JSON::serialize;
+    $self->{unserialize}  = \&Apache::Session::Serialize::JSON::unserialize;
 
     return $self;
 }
@@ -105,7 +102,10 @@ Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 by Xavier Guimard
+=encoding utf8
+
+Copyright (C) 2009-2013 by Xavier Guimard
+              2013 by Clément Oudot
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.1 or,
