@@ -5,10 +5,11 @@ use strict;
 use Apache::Session;
 use Apache::Session::Lock::Null;
 use Apache::Session::Browseable::Store::Postgres;
-use Apache::Session::Generate::MD5;
-use Apache::Session::Serialize::Base64;
+use Apache::Session::Generate::SHA256;
+use Apache::Session::Serialize::JSON;
+use Apache::Session::Browseable::DBI;
 
-our $VERSION = '0.1';
+our $VERSION = '1.2';
 our @ISA     = qw(Apache::Session::Browseable::DBI Apache::Session);
 
 sub populate {
@@ -17,10 +18,10 @@ sub populate {
     $self->{object_store} =
       new Apache::Session::Browseable::Store::Postgres $self;
     $self->{lock_manager} = new Apache::Session::Lock::Null $self;
-    $self->{generate}     = \&Apache::Session::Generate::MD5::generate;
-    $self->{validate}     = \&Apache::Session::Generate::MD5::validate;
-    $self->{serialize}    = \&Apache::Session::Serialize::Base64::serialize;
-    $self->{unserialize}  = \&Apache::Session::Serialize::Base64::unserialize;
+    $self->{generate}     = \&Apache::Session::Generate::SHA256::generate;
+    $self->{validate}     = \&Apache::Session::Generate::SHA256::validate;
+    $self->{serialize}    = \&Apache::Session::Serialize::JSON::serialize;
+    $self->{unserialize}  = \&Apache::Session::Serialize::JSON::unserialize;
 
     return $self;
 }
